FromClosureArgPointer

Trait FromClosureArgPointer 

pub trait FromClosureArgPointer {
    // Required method
    unsafe fn from_arg_ptr(ptr: *const c_void) -> Self;
}
Provides a general purpose way to deref a structure from a C void pointer. Auto implemented for Copy types.

Required Methods

unsafe fn from_arg_ptr(ptr: *const c_void) -> Self

Safety

Incorrect implementations of this trait may lead to undefined behavior. If you’re trying to read out a pointer type, then the pointer passed to this trait is a pointer to your pointer, not the pointer itself.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors